<?php
// $Id: leaguesite.inc,v 1.18 2010/07/05 17:40:32 alun Exp $

//this file will contain all the code for the viewing of the leagues

function leaguesite_view_seasons(){
	$output = '';
	//determine if there is only one season. If so, then display a table with the leagues from the seasons.
	//If there are multiple seasons available, then display a selection.
	//ALSO, consider that there may be no seasons currently running!
	$result = db_query("SELECT sid, name FROM {leaguesite_season} WHERE end >= UNIX_TIMESTAMP();");
	$seasons = array();
	while($row = db_fetch_array($result)){
		$seasons[] = array('sid' => $row['sid'], 'name' => $row['name']);
	}
	if(count($seasons) == 0){
		//no result
		//check for past seasons, or no result
	}else if(count($seasons) == 1){
		//one result, get the leagues involved
		$result = db_query("SELECT {leaguesite_league}.*, {leaguesite_relation}.relation_id, COUNT({leaguesite_standings}.relation_id) AS teams FROM {leaguesite_relation}, {leaguesite_league}, {leaguesite_standings} WHERE {leaguesite_relation}.sid = %d AND {leaguesite_league}.lid = {leaguesite_relation}.lid AND {leaguesite_standings}.relation_id = {leaguesite_relation}.relation_id GROUP BY {leaguesite_league}.name", $seasons[0]['sid']);
		while($row = db_fetch_array($result)){
			$leaguerows[] = array(
			l($row['name'], 'leaguesite/'.$row['relation_id']),
			check_plain($row['teams']),
			check_plain($row['weeks']),
			);
		}
	}else{
		//more than one result, maybe display the current season with the others in collapsible boxes? Maybe a pager for more than 5

	}
	$leagueheader = array(t('League Name'), t('Teams'), t('Weeks'));
	$output = theme('table', $leagueheader, $leaguerows);
	return $output;
}

function leaguesite_view_standings(){
	$relation = arg(1);
	if(is_numeric($relation)){
		$info = db_fetch_array(db_query("SELECT {leaguesite_season}.name AS season, {leaguesite_league}.name AS league, {leaguesite_league}.lid FROM {leaguesite_relation}, {leaguesite_league}, {leaguesite_season} WHERE {leaguesite_relation}.relation_id = %d AND {leaguesite_league}.lid = {leaguesite_relation}.lid AND {leaguesite_season}.sid = {leaguesite_relation}.sid;", $relation));
		drupal_set_title(t('Viewing %league - %season', array('%league' => $info['league'], '%season' => $info['season'])));
		$league_id = $info['lid'];
		$breadcrumb = array(l(t('Home'), ''), l(t('Leagues'), 'leaguesite'));
		drupal_set_breadcrumb($breadcrumb);
		$result = db_query("SELECT {node}.title, {node}.nid, {leaguesite_standings}.* FROM {leaguesite_standings}, {node} WHERE {node}.nid = {leaguesite_standings}.team_id AND {leaguesite_standings}.relation_id = %d ORDER BY {leaguesite_standings}.won DESC, {leaguesite_standings}.drawn DESC;", $relation);
		//get the teams
		while($row = db_fetch_array($result)){
			$leagueteam = $row['name'];
			$teams[] = array(
        'name' => l($row['title'], 'node/'.$row['nid']),
			  'won' => $row['won'],
        'drawn' => $row['drawn'],
        'lost' => $row['lost'],
        'goals_for' => $row['goals_for'],
        'goals_against' => $row['goals_against'],
        'bonus' => $row['bonus'],
			);
		}

		//sort them out
		//select the league scoring from the database and call a function that returns a sorted array with all the scores figured out.
		//also needs to be ordered for the table display.
		$score = db_fetch_array(db_query("SELECT {leaguesite_sports}.* FROM {leaguesite_sports}, {leaguesite_league}, {leaguesite_relation} WHERE {leaguesite_relation}.relation_id = %d AND {leaguesite_league}.lid = {leaguesite_relation}.lid AND {leaguesite_league}.sport_id = {leaguesite_sports}.sport_id;", $relation));
		$teams = _leaguesite_get_scores($teams, $score);
		//order the teams here, using the scoring method and adding the bonus points on.
		$teams = _leaguesite_order_teams($teams);
		
		//remove the unwanted fields from the standings table
		$teamsheader = _leaguesite_get_standings_fields($teams, $league_id);
	}
	$output = theme('table', $teamsheader, $teams);
	return $output;
}

/**
 * Private function that calculates the scores for the teams and returns a new array for display with the table on the page
 * @param Array $teams - the list of teams which need their scores calculated
 * @param Array $scoring - the scoring system, relational array containing a value for win, draw and loss
 * @return Array of teams ready for display, but not in order.
 */
function _leaguesite_get_scores($teams, $scoring){
	for($count = 0; $count < count($teams); ++$count){
		$newteams[] = array(
      'name' => $teams[$count]['name'],
      'played' => ($teams[$count]['won'] + $teams[$count]['drawn'] + $teams[$count]['lost']),
      'won' => $teams[$count]['won'],
      'drawn' => $teams[$count]['drawn'],
      'lost' => $teams[$count]['lost'],
      'goals_for' => $teams[$count]['goals_for'],
      'goals_against' => $teams[$count]['goals_against'],
      'points' => ($teams[$count]['won'] * $scoring['win']) + ($teams[$count]['drawn'] * $scoring['draw']) + ($teams[$count]['lost'] * $scoring['loss']) + $teams[$count]['bonus'],
		);
	}
	return $newteams;
}

/**
 * This private function can be used to get the heading for a league. When I start adding the option to display different fields
 * @param int $league_id = will be the league id. For now this doesn't matter, but I can start displaying different fields for different leagues if I want.
 * @return unknown_type
 */
function _leaguesite_get_standings_fields(&$teams, $league_id = 0){
	return array(t('Team Name'), t('P'), t('W'), t('D'), t('L'), t('F'), t('A'), t('Pts'));
}

/**
 *
 * @param unknown_type $teams
 * @return unknown_type
 */
function _leaguesite_order_teams($teams){
	//have an outer and an inner loop for a simple insertion sort. Might optimise this sometime in the future if needed.
	//bearing in mind, the database query already tries to order them, so they should be fairly OK.
	for($outcount = 0; $outcount < count($teams); ++$outcount){
		for($incount = 0; $incount < (count($teams)-1); ++$incount){
			if($teams[$incount]['points'] < $teams[$incount +1]['points']){
				//swap
				$teamtemp = $teams[$incount];
				$teams[$incount] = $teams[$incount+1];
				$teams[$incount+1] = $teamtemp;
			}
		}
	}
	return $teams;
}