<?php
/**
 * List the different types of scoring methods throughout all the games
 * @return unknown_type
 */
function leaguesite_methods_list(){
  $methods = db_query("SELECT * FROM {leaguesite_method};");
  $count = 0;
  $form['scoring'] = array('#type' => 'fieldset', '#title' => t('Scoring methods'));
  while($row = db_fetch_array($methods)){
    $form['scoring'][$row['method_id']]['name'] = array('#value' => $row['name'],);
    $form['scoring'][$row['method_id']]['points'] = array('#value' => $row['points']);
    $form['scoring'][$row['method_id']]['configure'] = array('#value' => l(t('configure'), 'admin/content/leaguesite/methods/'.$row['method_id'].'/edit'));
    $form['scoring'][$row['method_id']]['delete'] = array('#value' => $default ? '' : l(t('delete'), 'admin/content/leaguesite/methods/'.$row['method_id'].'/delete'));
    ++$count;
  }
  if($count == 0){
    $form['scoring']['notice'] = array('#value' => 'No scoring types currently exist. ');
  }
  
  //Now get the different types of penalties available.
  $pens = db_query("SELECT * FROM {leaguesite_penalty};");
  $count = 0;
  $form['penalty'] = array('#type' => 'fieldset', '#title' => t('Match penalties'));
  while($row = db_fetch_array($pens)){
    $form['penalty'][$row['penalty_id']]['name'] = array('#value' => $row['name'],);
    $form['penalty'][$row['penalty_id']]['delete'] = array('#value' => l(t('delete'), 'admin/content/leaguesite/penalty/'.$row['penalty_id'].'/delete'));
    ++$count;
  }
  if($count == 0){
    $form['penalty']['notice'] = array('#value' => 'No penalties currently exist. ');
  }
  return $form;
}

/**
 * Theme the table of scoring methods
 * @return unknown_type
 */
function theme_leaguesite_methods_list($form){
  $rows = array();
  foreach ($form['scoring'] as $name => $element) {
    if(is_array($element['name'])){
      $rows[] = array(
      drupal_render($element['name']),
      drupal_render($element['points']),
      drupal_render($element['configure']),
      drupal_render($element['delete'])
      );
      unset($form['scoring'][$name]);
    }
  }

  $header = array(t('Method Name'), t('Points'), array('data' => t('Operations'), 'colspan' => 2));
  if(count($rows) > 0){
    $output = theme('table', $header, $rows);
  }
  $output .= l('Add a new score method', 'admin/content/leaguesite/methods/add');
  $form['scoring']['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  $output = '';
  $rows = array();
  foreach ($form['penalty'] as $name => $element) {
    if(is_array($element['name'])){
      $rows[] = array(
      drupal_render($element['name']),
      drupal_render($element['delete'])
      );
      unset($form['penalty'][$name]);
    }
  }

  $header = array(t('Penalty Name'), t('Delete'));
  if(count($rows) > 0){
    $output = theme('table', $header, $rows);
  }
  $output .= l('Add a new penalty', 'admin/content/leaguesite/penalty/add');
  $form['penalty']['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  return drupal_render($form);
}

function leaguesite_score_penalty_add(){
  $form = array();
  //add a new season
  $form['penalty_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('The name of the penalty, e.g. Red Card'),
    '#size' => 30,
    '#maxlength' => 50,
    '#required' => TRUE,
  );

  $form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create Scoring Method')
  );
  return $form;
}
function leaguesite_score_penalty_add_submit($form, $form_state){
  $name = check_plain($form_state['values']['penalty_name']);
  db_query("INSERT INTO {leaguesite_penalty} (name) VALUES ('%s');", $form_state['values']['penalty_name']);
  drupal_set_message(t('Added penalty %method.', array('%method' => $name)));
}

function leaguesite_score_method_add(){
	$form = array();
  //add a new season
  $form['method_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('The name of the score method, e.g. penalty'),
    '#size' => 30,
    '#maxlength' => 50,
    '#required' => TRUE,
  );

  $form['method_points'] = array(
    '#type' => 'textfield',
    '#title' => t('Value'),  
    '#description' => t('How many points is the score method worth?'),
    '#size' => 4,
    '#maxlength' => 4,
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create Scoring Method')
  );
  return $form;
}

function leaguesite_score_method_add_submit($form, $form_state){
	$name = check_plain($form_state['values']['method_name']);
	db_query("INSERT INTO {leaguesite_method} (name, points) VALUES ('%s', '%d');", $form_state['values']['method_name'], $form_state['values']['method_points']);
	drupal_set_message(t('Added score method %method.', array('%method' => $name)));
}
/**
 * Form that confirms the deletion of the penalty
 */
function leaguesite_score_penalty_delete(){
  $penalty = arg(4);
  $penalty = db_fetch_array(db_query('SELECT * FROM {leaguesite_penalty} WHERE penalty_id = %d;', $penalty));
  if ($penalty) {
    $form['penalty'] = array('#type' => 'hidden', '#value' => $penalty['penalty_id']);
    $form['name'] = array('#type' => 'hidden', '#value' => $penalty['name']);
    return confirm_form($form, t('Are you sure you want to delete the penalty %penalty?', array('%penalty' => $penalty['name'])), 'admin/content/leaguesite/methods/list', t('Warning! If you have used this penalty in match breakdowns and delete it, it may cause problems with matches that use it.'), t('Delete'), t('Cancel'));
  }
  else {
    drupal_not_found();
  }
}
/**
 * Deletes the penalty
 */
function leaguesite_score_penalty_delete_submit($form, $form_state){
  //TODO: I will have to check that this doesn't affect any games. I shouldn't allow people to delete it if it does, because it is not easily undone.
  $penalty_id = $form_state['values']['penalty'];
  db_query("DELETE FROM {leaguesite_penalty} WHERE penalty_id = %d", $penalty_id);
  drupal_set_message(t('Penalty deleted.'));
  drupal_goto('admin/content/leaguesite/methods/list');
}

function leaguesite_score_method_edit(){
	//add breadcrumb for easy navigation back
	$breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = l(t('Methods'), 'admin/content/leaguesite/methods/list');
  drupal_set_breadcrumb($breadcrumb);
  
	$method = arg(4);
  if(is_numeric($method)){
    $result = db_fetch_array(db_query("SELECT * FROM {leaguesite_method} WHERE method_id = %d", $method));
	  $form = array();
    //add a new season
    $form['method_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Name'),
      '#description' => t('The name of the score method, e.g. penalty'),
      '#size' => 30,
      '#maxlength' => 50,
      '#required' => TRUE,
      '#default_value' => $result['name'],
    );
    $form['method_points'] = array(
      '#type' => 'textfield',
      '#title' => t('Value'),  
      '#description' => t('How many points is the score method worth?'),
      '#size' => 4,
      '#maxlength' => 4,
      '#required' => TRUE,
      '#default_value' => $result['points'],
    );
    $form['submit'] = array(
      '#type' => 'submit', '#value' => t('Amend Scoring Method')
    );
  }
  return $form;
}

/**
 * Form that confirms the deletion of the score method
 */
function leaguesite_score_method_delete(){
  $method = arg(4);
  $method = db_fetch_array(db_query('SELECT * FROM {leaguesite_method} WHERE method_id = %d;', $method));
  if ($method) {
    $form['method'] = array('#type' => 'hidden', '#value' => $method['method_id']);
    $form['name'] = array('#type' => 'hidden', '#value' => $method['name']);
    return confirm_form($form, t('Are you sure you want to delete the score method %method?', array('%method' => $method['name'])), 'admin/content/leaguesite/methods/list', t('Warning! If you have used this scoring method in match results and delete it, it may cause problems with matches that use this score method.'), t('Delete'), t('Cancel'));
  }
  else {
    drupal_not_found();
  }
}

/**
 * Deletes the score method
 */
function leaguesite_score_method_delete_submit($form, $form_state){
  //TODO: I will have to check that this doesn't affect any games. I shouldn't allow people to delete it if it does, because it is not easily undone.
  $method_id = $form_state['values']['method'];
  db_query("DELETE FROM {leaguesite_method} WHERE method_id = %d", $method_id);
  drupal_set_message(t('Method deleted.'));
  drupal_goto('admin/content/leaguesite/methods/list');
}

/**
 * This function gets the current methods assigned to a scoring type and lists them, with options to remove.
 */
function leaguesite_type_methods_view(){
	$type = arg(4);
	if(!is_numeric($type)){
		drupal_not_found();
	}else{
    $methods = db_query("SELECT * FROM {leaguesite_method}, {leaguesite_sport_method} WHERE {leaguesite_sport_method}.method_id = {leaguesite_method}.method_id AND {leaguesite_sport_method}.sport_id = %d;", $type);
    $count = 0;

    while($row = db_fetch_array($methods)){
    	$form[$count]['rid'.$count] = array('#type' => 'hidden', '#value' => $row['rid']);
    	$form[$count]['checkbox'.$count] = array('#type' => 'checkbox');
      $form[$count]['name'.$count] = array('#value' => $row['name'],);
      $form[$count]['points'.$count] = array('#value' => $row['points']);
      ++$count;
    }
    if($count == 0){
      $form['notice'] = array('#value' => 'No scoring types currently exist.');
    }else{
    	$form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Remove selected'),
    	);
    }
    return $form;
	}
}

/**
 * Theme the list of scoring methods assigned to a scoring type
 */
function theme_leaguesite_type_methods_view($form){
	$type = arg(4);
  $scorerows = array();
  $count = 0;
  foreach ($form as $name => $element) {
    if(is_array($element['name'.$name])){
      $scorerows[] = array(
      drupal_render($element['checkbox'.$name]),
      drupal_render($element['name'.$name]),
      drupal_render($element['points'.$name]),
      );
      unset($form[$name]);
      ++$count;
    }
  }
  $seasonheader = array('', t('Method Name'), t('Points'));
  if(count($scorerows) > 0){
    $output = theme('table', $seasonheader, $scorerows);
  }
  $output .= drupal_render($form);
  $output .= '<br />'.l('Assign a new score method to this sport', 'admin/content/leaguesite/sport/'.$type.'/add/methods');
  return $output;
}

function leaguesite_type_methods_view_submit($form, $form_state){
  for($id = 0; isset($form_state['values']['rid'.$id]); ++$id){
  	if($form_state['values']['checkbox'.$id] == 1){
      db_query('DELETE FROM {leaguesite_sport_method} WHERE rid = %d;', $form_state['values']['rid'.$id]);
      drupal_set_message(t('Method removed'));
  	}
  }
}

/**
 * This function provides a form for a user to add scoring methods to a scoring type. I should get the scoring methods currently created, and list them for the user to select.
 */
function leaguesite_type_methods_add(){
	$type = arg(4);
	//get the score type to clarify to the user what they are doing in the page title
	$name = db_fetch_array(db_query('SELECT name FROM {leaguesite_sports} WHERE sport_id = %d', $type));
	$name = $name['name'];
	drupal_set_title(t('Add scoring method to %sport', array('%sport' => $name)));
	//firstly get the scoring methods
	$all_methods = db_query('SELECT * FROM {leaguesite_method} ORDER BY method_id;');
	//then get the ones which are selected so we can not include them. There should be a way to do this in one query.
	$enabled_methods_result = db_query("SELECT {leaguesite_method}.* FROM {leaguesite_method}, {leaguesite_sport_method} WHERE {leaguesite_sport_method}.method_id = {leaguesite_method}.method_id AND {leaguesite_sport_method}.sport_id = %d ORDER BY {leaguesite_method}.method_id;", $type);
	$enabled_methods = db_fetch_array($enabled_methods_result);
	$count = 0;
	$enabled_count = 0;
	//loop through and add the disabled score types so the list of checkboxes for people to tick and then a submit button at the bottom. Simples.
  while($row = db_fetch_array($all_methods)){
    if($enabled_methods['method_id'] == $row['method_id']){
      //the current row is present in the league.
      $ignore = TRUE;
      ++$enabled_count;
      //get the next enabled one
      $enabled_methods = db_fetch_array($enabled_methods_result);
    }else{
      $ignore = FALSE;
      ++$count;
    }
    if(!$ignore){
      $form['teams'][$row['method_id']] = array(
        '#type' => 'checkbox',
        '#title' => $row['name'].' ('.$row['points'].' points)',
      );
    }
  }
  if($count == 0 && $enabled_count == 0){
    $form['methods']['label'] = array(
      '#value' => t('No score methods added yet, go to ').l(t('add score method'), 'admin/content/leaguesite/methods/add').t(' to add some'),
    );
  }else if($count == 0 && $enabled_count > 0){
  	$form['methods']['label'] = array(
      '#value' => t('All of your score methods are added to this scoring type! To add more methods, go to ').l(t('add score method'), 'admin/content/leaguesite/methods/add'),
    );
  }else{
    $form['submit'] = array(
      '#type' => 'submit', '#value' => t('Add Methods')
    );
  }
  return $form;
}

/**
 * Function to add the score methods to the sport
 * @return unknown_type
 */
function leaguesite_type_methods_add_submit($form, $form_state){
  $type = arg(4);
  if(!is_numeric($type)){
    drupal_not_found();
  }else{
    //loop through the form league values and add the scoring method if checked
    foreach($form_state['values'] as $id => $checked){
      //we don't have to worry about unchecked boxes, just checked ones.
      if($checked == 1){
        //if checked equals 1, then add the relation
        db_query("INSERT INTO {leaguesite_sport_method} (method_id, sport_id) VALUES (%d, %d)", $id, $type);
        //TODO: drupal_set_message(t('Added score method %method to %sport.', array('%method' => $name, '%sport' => $sport_name))); //for each type added?
      }
    }
    drupal_set_message("Changes Saved");
  }
}

/**
 * This function takes a match result and constructs a form which allows the user to enter their breakdown of a match
 * For example, given a football result of 3-2, we could ask the user to enter the players (if the players module is enabled)
 * who scored the goal and also who assissted the goal.
 * If the players module is enabled, but no players are on the team (the website might just be focusing on one team) then 
 * the user is presented with a text box which can create a player for the sole purpose of adding them to the details of a game.
 * We can also ask the time in the game of the scores.
 * Another option we will want is any penalties that have been awarded in the game. For example in a large number of sports,
 * you will have yellow and red cards. We can assign these to players and again give them a time.
 * @return unknown_type
 */
function leaguesite_scoring_create_breakdown($form_state = array()){
	$form = array();
	$form['#cache'] = TRUE;
  if(isset($form_state['values'])){
	  $match_id = $form_state['values']['match_id'];
  }else{
	  $match_id = intval(arg(1));
  }
  //Get the home team and away team details.
  $score = db_fetch_array(db_query('SELECT home.title AS home_name, away.title AS away_name, {leaguesite_match}.home_team, {leaguesite_match}.away_team FROM {leaguesite_match} LEFT JOIN {node} home ON {leaguesite_match}.home_team = home.nid LEFT JOIN {node} away ON {leaguesite_match}.away_team = away.nid WHERE {leaguesite_match}.nid = %d', $match_id));
  $form['home_team'] = array(
    '#type' => 'hidden',
    '#value' => $score['home_team'],
  );
  $form['away_team'] = array(
    '#type' => 'hidden',
    '#value' => $score['away_team'],
  );
  $form['home_name'] = array(
    '#type' => 'hidden',
    '#value' => $score['home_name'],
  );
  $form['away_name'] = array(
    '#type' => 'hidden',
    '#value' => $score['away_name'],
  );
	if(isset($form_state['values'])){
		$values = $form_state['values'];
	  $homesubs = $values['homesubs'];
	  $awaysubs = $values['awaysubs'];
    $homepens = $values['homepens'];
    $awaypens = $values['awaypens'];
	}else{
		//Get details from the database to see if the match breakdown has been entered before
		//we don't need to do this if the form is being resubmitted, hence calling it inside the if statement.
		$values = array();
		$match = db_query('SELECT {leaguesite_event}.*, player_on.first_name AS player_on_first_name, player_on.last_name AS player_on_last_name, player.first_name AS player_first_name, player.last_name AS player_last_name, player.nid AS player_nid, player_on.nid AS player_on_nid FROM {leaguesite_event} LEFT JOIN {leaguesite_player} player ON {leaguesite_event}.player_id = player.player_id LEFT JOIN {leaguesite_player} player_on ON {leaguesite_event}.player_on_id = player_on.player_id WHERE match_id = %d', $match_id);
		$count = 0;
		$homepencount = 0;
		$awaypencount = 0;
		$homescorecount = 0;
		$awayscorecount = 0;
		$homesubcount = 0;
		$awaysubcount = 0;
		while($row = db_fetch_array($match)){
			switch($row['event_type']){
				case 'pen':
					switch($row['team_id']){
						case $form['home_team']['#value']:
						  $values['homepentype'.$homepencount] = $row['pen_score_id'];
						  $values['homepenplayer'.$homepencount] = $row['player_id'];
						  if($row['player_nid'] == -1){
						    $values['homepenplayer'.$homepencount] = $row['player_first_name'].' '.$row['player_last_name'];
						  }
						  $values['homepentime'.$homepencount] = $row['time'];
							++$homepencount;
							break;
						case $form['away_team']['#value']:
							$values['awaypentype'.$awaypencount] = $row['pen_score_id'];
              $values['awaypenplayer'.$awaypencount] = $row['player_id'];
              if($row['player_nid'] == -1){
                $values['awaypenplayer'.$awaypencount] = $row['player_first_name'].' '.$row['player_last_name'];
              }
              $values['awaypentime'.$awaypencount] = $row['time'];
              ++$homepencount;
							break;
					}
					break;
				case 'score':
			    switch($row['team_id']){
            case $form['home_team']['#value']:
              $values['homescoremethod'.$homescorecount] = $row['pen_score_id'];
              $values['homescoreplayer'.$homescorecount] = $row['player_id'];
              if($row['player_nid'] == -1){
                $values['homescoreplayer'.$homescorecount] = $row['player_first_name'].' '.$row['player_last_name'];
              }
              $values['homescoretime'.$homescorecount] = $row['time'];
              ++$homescorecount;
              break;
            case $form['away_team']['#value']:
              $values['awayscoremethod'.$awayscorecount] = $row['pen_score_id'];
              $values['awayscoreplayer'.$awayscorecount] = $row['player_id'];
              if($row['player_nid'] == -1){
                $values['awayscoreplayer'.$awayscorecount] = $row['player_first_name'].' '.$row['player_last_name'];
              }
              $values['awayscoretime'.$awayscorecount] = $row['time'];
              ++$awayscorecount;
              break;
          }
					break;
				case 'sub':
			    switch($row['team_id']){
            case $form['home_team']['#value']:
              //$values['homesubmethod'.$homesubcount] = $row['pen_score_id'];
              $values['homesuboff'.$homesubcount] = $row['player_id'];
              $values['homesubon'.$homesubcount] = $row['player_on_id'];
              if($row['player_nid'] == -1){
                $values['homesubon'.$homesubcount] = $row['player_first_name'].' '.$row['player_last_name'];
                $values['homesuboff'.$homesubcount] = $row['player_on_first_name'].' '.$row['player_on_last_name'];
              }
              $values['homesubtime'.$homesubcount] = $row['time'];
              ++$homesubcount;
              break;
            case $form['away_team']['#value']:
              //$values['awaysubmethod'.$awaysubcount] = $row['pen_score_id'];
              $values['awaysuboff'.$awaysubcount] = $row['player_id'];
              $values['awaysubon'.$awaysubcount] = $row['player_on_id'];
              if($row['player_nid'] == -1){
                $values['awaysuboff'.$awaysubcount] = $row['player_first_name'].' '.$row['player_last_name'];
                $values['awaysubon'.$awaysubcount] = $row['player_on_first_name'].' '.$row['player_on_last_name'];
              }
              $values['awaysubtime'.$awaysubcount] = $row['time'];
              ++$awaysubcount;
              break;
          }
					++$subcount;
					break;
			}
			++$count;
		}
		if($count == 0){
		  $homesubs = 1;
		  $awaysubs = 1;
      $homepens = 1;
      $awaypens = 1;
		}else{
			$homesubs = $homesubcount == 0 ? 1 : $homesubcount;
			$awaysubs = $awaysubcount == 0 ? 1 : $awaysubcount;
			$homepens = $homepencount == 0 ? 1 : $homepencount;
			$awaypens = $awaypencount == 0 ? 1 : $awaypencount;
		}
	}
	//set the match_id to be used in ahah callbacks.
	$form['match_id'] = array(
	  '#type' => 'hidden',
	  '#value' => $match_id,
	);
	
  if(isset($form_state['breakdown_selection'])){
  	switch($form_state['post']['leaguesite_submit_id']){
  		case 'homepens':
  			$homepens += 2;
  			break;
  		case 'homesubs':
  			$homesubs += 2;
  			break;
  		case 'awaysubs':
        $awaysubs += 2;
        break;
  		case 'awaypens':
  			$awaypens += 2;
  			break;
  		default:
  			//this will be called if the user is not using Javascript, and therefore we should just add two to both subs and pens, as we can't identify which button was clicked
  			$homesubs += 2;
  			$awaysubs += 2;
  			$homepens += 2;
  			$awaypens += 2;
  			break;
  	}
  }
  
	/* Things that are needed:
	 * (if players module is enabled) Select the person who scored or display a textbox to enter the name of who scored.
	 * Time of score. Assists.
	 * 
	 * Cards - I need to allow a user to enter yellow and red cards in a game.
	 * Should also allow more than just yellow and red. Perhaps allow a user to describe penalties,
	 * which they can then assign to players along with a time in the game
	 * 
	 * (If players module is enabled) Substitutes - Players come on and go off. I should assign times for when they started and left.
	 */
  //get a list of penalties for the selections
  //for the moment, I'll just create a temporary list
  $penalty_list = db_query('SELECT * FROM {leaguesite_penalty};');
  $penalties = array('none' => t('Please select'));
  while($row = db_fetch_array($penalty_list)){
  	$penalties[$row['penalty_id']] = $row['name'];
  }
  $home_player_module = FALSE;
  $away_player_module = FALSE;
  $player_module = FALSE;
  //check if players module is enabled. if so, get a list of players for the penalty to be attributed to.
	if(module_exists('leaguesite_player')){
		$players_list = db_query('SELECT {node}.title, {leaguesite_player_match}.player_id, {leaguesite_player_match}.team_id FROM {leaguesite_player_match} LEFT JOIN {leaguesite_player} ON {leaguesite_player_match}.player_id = {leaguesite_player}.player_id LEFT JOIN {node} ON {leaguesite_player}.nid = {node}.nid WHERE {leaguesite_player_match}.match_id = %d', intval($match_id));
		
		$players = array('none' => t('Please select'));
		$homeplayers = array('none' => t('Please select'));
		$awayplayers = array('none' => t('Please select'));
		while($row = db_fetch_array($players_list)){
			$players[$row['player_id']] = $row['title'];
			if($row['team_id'] == $form['home_team']['#value']){
				$homeplayers[$row['player_id']] = $row['title'];
			}else{
				$awayplayers[$row['player_id']] = $row['title'];
			}
		}
		$player_module = TRUE;
		if(count($homeplayers) > 1){
		  $home_player_module = TRUE;
		  $player_module = TRUE;
		}else{
			$home_player_module = FALSE;
		}
		if(count($awayplayers) > 1){
			$away_player_module = TRUE;
			$player_module = TRUE;
		}else{
			$away_player_module = FALSE;
		}
	}else{
		$player_module = FALSE;
		$away_player_module = FALSE;
		$home_player_module = FALSE;
		
	}
	/*
	 * The combination of $home_player_module and $away_player_module and $player_module will inform us about what we need on the
	 * breakdown screen. For example, if $player_module == TRUE but $away_player_module == FALSE, then we can use textboxes in the place
	 * of dropdown boxes to enter the name of a player for this away team only. 
	 */
	
	
  
	/*
   * This form will be setup to allow people to enter the players and times for the scores entered on the previosu form.
   * For each quantity of scoring type, we will have either a dropdown box for a user to select the player who scored
   * or a textbox to enter the name of the player.
   * For each goal, there will be an option to add assists. This should be available in a similar fashion to the penalties -
   * an add more button to add more assists.
   */
  $form['scores'] = array(
    '#title' => t('Scoring details'),
    '#type' => 'fieldset',
    '#prefix' => '<div class="clear-block" id="leaguesite-scoring_scores-wrapper">',
    '#suffix' => '</div>',
    '#theme' => 'leaguesite_scoring_scores',
  );
  
  /* Here, we get the scoring details. We will have each score, separated by team, and present the user with two tables, so they can outline the details of each goal.
   * lets start with the scoring details
   * 
   */
  $scores = db_query('SELECT {leaguesite_match_attribute}.home_score_quantity, {leaguesite_match_attribute}.away_score_quantity, {leaguesite_match_attribute}.method_id, {leaguesite_match}.home_team, {leaguesite_match}.away_team, {leaguesite_method}.name FROM {leaguesite_match_attribute} LEFT JOIN {leaguesite_method} ON {leaguesite_match_attribute}.method_id = {leaguesite_method}.method_id LEFT JOIN {leaguesite_match} ON {leaguesite_match_attribute}.match_id = {leaguesite_match}.nid WHERE {leaguesite_match_attribute}.match_id = %d', $match_id);
  $homecount = 0;
  $awaycount = 0;
  while($score = db_fetch_array($scores)){
  	$form['scores']['home_name'] = $form['home_name'];
  	$form['scores']['away_name'] = $form['away_name'];
  	//we need a new row for each different score type, and a new table for each team.
  	for($count = 0; $count < $score['home_score_quantity']; ++$count){
  		
  	  $form['scores']['home']['homescoretime'.($count + $homecount)] = array(
  	    '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['homescoretime'.($count + $homecount)],
  	  );
  	  $form['scores']['home']['homescoremethod'.($count + $homecount)] = array(
  	    '#type' => 'hidden',
  	    '#value' => $score['method_id'], 
  	  );
  	  $form['scores']['home']['homescorename'.($count + $homecount)] = array(
  	    '#type' => 'label',
  	    '#value' => $score['name'],
  	  );
  	  if($home_player_module){
  	    $form['scores']['home']['homescoreplayer'.($count + $homecount)] = array(
  	      '#type' => 'select',
  	      '#options' => $players,
  	      '#default_value' => $values['homescoreplayer'.($count + $homecount)],
  	    );
  	    $form['scores']['home']['homescoreplayertype'.($count + $homecount)] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
  	  }else if($player_module){
  	  	$form['scores']['home']['homescoreplayer'.($count + $homecount)] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['homescoreplayer'.($count + $homecount)],
        );
        $form['scores']['home']['homescoreplayertype'.($count + $homecount)] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
  	  }
  	}
  	$homecount = $count;
  	for($count = 0; $count < $score['away_score_quantity']; ++$count){
  		$form['scores']['away']['awayscoretime'.($count + $awaycount)] = array(
        '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['awayscoretime'.($count + $awaycount)],
      );
      $form['scores']['away']['awayscoremethod'.($count + $awaycount)] = array(
        '#type' => 'hidden',
        '#value' => $score['method_id'], 
      );
      $form['scores']['away']['awayscorename'.($count + $awaycount)] = array(
        '#type' => 'label',
        '#value' => $score['name'],
      );
      
      if($away_player_module){
        $form['scores']['away']['awayscoreplayer'.($count + $awaycount)] = array(
          '#type' => 'select',
          '#options' => $players,
          '#default_value' => $values['awayscoreplayer'.($count + $awaycount)],
        );
        $form['scores']['away']['awayscoreplayertype'.($count + $awaycount)] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
      }else if($player_module){
      	$form['scores']['away']['awayscoreplayer'.($count + $awaycount)] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['awayscoreplayer'.($count + $awaycount)],
        );
        $form['scores']['away']['awayscoreplayertype'.($count + $awaycount)] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
      }
  	}
  	$awaycount = $count;
  }
  
  /*This isn't needed for scores so I commented it out. Might be needed to add assists though, so I've not deleted it.
   * $form['scores']['score_submit'] = array(
    '#type' => 'submit',
    '#value' => t('More'),
    '#prefix' => '<div id="leaguesite_scores_more_submit">',
    '#suffix' => '</div>',
    '#submit' => array('leaguesite_scoring_ahah_submit'),
    '#weight' => 5,
    '#ahah' => array(
      'path' => 'leaguesite/scores_options',
      'wrapper' => 'leaguesite-scoring_scores-wrapper',
      'method' => 'replace',
      'effect' => 'fade',
    ),
  );*/
  
  /*
   * Here we will have two boxes for the user to select players and times and penalties awarded.
   * If the players module does not exist, we could allow the user to type the players name?
   * This could set up a player with this name for use in the game report.
   * There will be an 'add more' button to add more penalties.
   * We will only display penalty options if there are any penalties in the game. 
   */
  if(count($penalties) > 0){
    $form['homepenalties'] = array(
      '#title' => $form['home_name']['#value'].' '.t('Penalties'),
      '#type' => 'fieldset',
      '#prefix' => '<div class="clear-block" id="leaguesite-scoring_home_penalties-wrapper">',
      '#suffix' => '</div>',
      '#theme' => 'leaguesite_scoring_home_penalties',
    );
    for($count = 0; $count < $homepens; ++$count){
      $form['homepenalties'][$count]['homepentime'.$count] = array(
        '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['homepentime'.$count],
      );
      //only add the player list if the player module is enabled
      //we checked earlier if it was, so we just use that variable, to save a db query and therefore time.
      if($home_player_module){
        $form['homepenalties'][$count]['homepenplayer'.$count] = array(
          '#type' => 'select',
          '#options' => $homeplayers,
          '#default_value' => $values['homepenplayer'.$count],
        );
        $form['homepenalties'][$count]['homepenplayertype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
      }else if($player_module){
      	$form['homepenalties'][$count]['homepenplayer'.$count] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['homepenplayer'.$count],
        );
        $form['homepenalties'][$count]['homepenplayertype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
      }
    
      $form['homepenalties'][$count]['homepentype'.$count] = array(
        '#type' => 'select',
        '#options' => $penalties,
        '#default_value' => $values['homepentype'.$count],
      );
      //get a list of penalties possible. I need to allow a user to enter them.
    }
    $form['homepenalties']['homepens'] = array(
      '#type' => 'hidden',
      '#default_value' => $homepens,
    );
    $form['homepenalties']['homepen_submit'] = array(
      '#type' => 'submit',
      '#value' => t('More'),
      '#prefix' => '<div id="leaguesite_homepenalties_submit">',
      '#suffix' => '</div>',
      '#submit' => array('leaguesite_scoring_ahah_submit'),
      '#weight' => 5,
      '#ahah' => array(
        'path' => 'leaguesite/home_penalties_options',
        'wrapper' => 'leaguesite-scoring_home_penalties-wrapper',
        'method' => 'replace',
        'effect' => 'fade',
      ),
    );
    
    //and again for the away team
    $form['awaypenalties'] = array(
      '#title' => $form['away_name']['#value'].' '.t('Penalties'),
      '#type' => 'fieldset',
      '#prefix' => '<div class="clear-block" id="leaguesite-scoring_away_penalties-wrapper">',
      '#suffix' => '</div>',
      '#theme' => 'leaguesite_scoring_away_penalties',
    );
    for($count = 0; $count < $awaypens; ++$count){
      $form['awaypenalties'][$count]['awaypentime'.$count] = array(
        '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['awaypentime'.$count],
      );
      //only add the player list if the player module is enabled
      //we checked earlier if it was, so we just use that variable, to save a db query and therefore time.
      
     if($away_player_module){
       $form['awaypenalties'][$count]['awaypenplayer'.$count] = array(
          '#type' => 'select',
          '#options' => $awayplayers,
          '#default_value' => $values['awaypenplayer'.$count],
        );
        $form['awaypenalties'][$count]['awaypenplayertype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
      }else if($player_module){
      	$form['awaypenalties'][$count]['awaypenplayer'.$count] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['awaypenplayer'.$count],
        );
        $form['awaypenalties'][$count]['awaypenplayertype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
      }
    
      $form['awaypenalties'][$count]['awaypentype'.$count] = array(
        '#type' => 'select',
        '#options' => $penalties,
        '#default_value' => $values['awaypentype'.$count],
      );
      //get a list of penalties possible. I need to allow a user to enter them.
    }
    $form['awaypenalties']['awaypens'] = array(
      '#type' => 'hidden',
      '#default_value' => $awaypens,
    );
    $form['awaypenalties']['awaypen_submit'] = array(
      '#type' => 'submit',
      '#value' => t('More'),
      '#prefix' => '<div id="leaguesite_awaypenalties_submit">',
      '#suffix' => '</div>',
      '#submit' => array('leaguesite_scoring_ahah_submit'),
      '#weight' => 5,
      '#ahah' => array(
        'path' => 'leaguesite/away_penalties_options',
        'wrapper' => 'leaguesite-scoring_away_penalties-wrapper',
        'method' => 'replace',
        'effect' => 'fade',
      ),
    );
  }
  /*
   * The substitutions, as with the penalties will have an add more button.
   * If the players module is enabled, administrators can select the player coming on,
   * and the player going off, and the time of the exchange.
   * If the players module is not selected, this substitution box should not be present.
   */
  if($player_module){
    $form['homesubstitutions'] = array(
      '#title' => $form['home_name']['#value'].' '.t('Substitutions'),
      '#type' => 'fieldset',
      '#prefix' => '<div class="clear-block" id="leaguesite-scoring_home_substitutions-wrapper">',
      '#suffix' => '</div>',
      '#theme' => 'leaguesite_scoring_home_substitutions',
    );
    
    for($count = 0; $count < $homesubs; ++$count){
      $form['homesubstitutions'][$count]['homesubtime'.$count] = array(
        '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['homesubtime'.$count]
      );
      if($home_player_module){
        //dropdown boxes for players playing
        $form['homesubstitutions'][$count]['homesuboff'.$count] = array(
          '#type' => 'select',
          '#options' => $homeplayers,
          '#default_value' => $values['homesuboff'.$count],
        );
        $form['homesubstitutions'][$count]['homesubofftype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
        $form['homesubstitutions'][$count]['homesubon'.$count] = array(
          '#type' => 'select',
          '#options' => $homeplayers,
          '#default_value' => $values['homesubon'.$count],
        );
        $form['homesubstitutions'][$count]['homesubontype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
      }else{
        $form['homesubstitutions'][$count]['homesuboff'.$count] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['homesuboff'.$count],
        );
        $form['homesubstitutions'][$count]['homesubofftype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
        $form['homesubstitutions'][$count]['homesubon'.$count] = array(
          '#type' => 'textfield',
          '#size' => 30,
          '#default_value' => $values['homesubon'.$count],
        );
        $form['homesubstitutions'][$count]['homesubontype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        );
      }
      
    }
    $form['homesubtitutions']['homesubs'] = array(
      '#type' => 'hidden',
      '#value' => $homesubs,
    );
    
    $form['homesubstitutions']['homesub_submit'] = array(
      '#type' => 'submit',
      '#value' => t('More'),
      '#hidden' => TRUE,
      '#prefix' => '<div id="leaguesite_home_substitutions_submit">',
      '#suffix' => '</div>',
      '#submit' => array('leaguesite_scoring_ahah_submit'),
      '#weight' => 5,
      '#ahah' => array(
        'path' => 'leaguesite/home_substitutions_options',
        'wrapper' => 'leaguesite-scoring_home_substitutions-wrapper',
        'method' => 'replace',
        'effect' => 'fade',
      ),
    );
  }
  
  if($player_module){
    //and the away substitutions...
    
    $form['awaysubstitutions'] = array(
      '#title' => $form['away_name']['#value'].' '.t('Substitutions'),
      '#type' => 'fieldset',
      '#prefix' => '<div class="clear-block" id="leaguesite-scoring_away_substitutions-wrapper">',
      '#suffix' => '</div>',
      '#theme' => 'leaguesite_scoring_away_substitutions',
    );
    for($count = 0; $count < $awaysubs; ++$count){
      $form['awaysubstitutions'][$count]['awaysubtime'.$count] = array(
        '#type' => 'textfield',
        '#size' => 3,
        '#required' => FALSE,
        '#maxlength' => 3,
        '#default_value' => $values['awaysubtime'.$count]
      );
      if($away_player_module){
        //dropdown boxes for players playing
        $form['awaysubstitutions'][$count]['awaysuboff'.$count] = array(
          '#type' => 'select',
          '#options' => $awayplayers,
          '#default_value' => $values['awaysuboff'.$count],
        );
        $form['awaysubstitutions'][$count]['awaysubofftype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        );
        $form['awaysubstitutions'][$count]['awaysubon'.$count] = array(
          '#type' => 'select',
          '#options' => $awayplayers,
          '#default_value' => $values['awaysubon'.$count],
        );
        $form['awaysubtitutions'][$count]['awaysubontype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'select',
        ); 
      }else{
      	//add textboxes instead of dropdowns
      	$form['awaysubstitutions'][$count]['awaysuboff'.$count] = array(
          '#type' => 'textfield',
      	  '#size' => '30',
          '#default_value' => $values['awaysuboff'.$count],
        );
        $form['awaysubstitutions'][$count]['awaysubofftype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        ); 
        $form['awaysubstitutions'][$count]['awaysubon'.$count] = array(
          '#type' => 'textfield',
          '#size' => '30',
          '#default_value' => $values['awaysubon'.$count],
        );
        $form['awaysubtitutions'][$count]['awaysubontype'.$count] = array(
          '#type' => 'hidden',
          '#value' => 'textfield',
        ); 
      }
      
    }
    $form['awaysubtitutions']['awaysubs'] = array(
      '#type' => 'hidden',
      '#value' => $awaysubs,
    );
    
    $form['awaysubstitutions']['awaysub_submit'] = array(
      '#type' => 'submit',
      '#value' => t('More'),
      '#hidden' => TRUE,
      '#prefix' => '<div id="leaguesite_away_substitutions_submit">',
      '#suffix' => '</div>',
      '#submit' => array('leaguesite_scoring_ahah_submit'),
      '#weight' => 5,
      '#ahah' => array(
        'path' => 'leaguesite/away_substitutions_options',
        'wrapper' => 'leaguesite-scoring_away_substitutions-wrapper',
        'method' => 'replace',
        'effect' => 'fade',
      ),
    );
  }
  
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  
  return $form;
}

function theme_leaguesite_scoring_scores($form){
	$count = 0;
  while(isset($form['home']['homescorename'.$count])) {
  	$element = $form['home'];
    if(is_array($element['homescoremethod'.$count])){
    	if(isset($element['homescoreplayer'.$count])){
    	  $homerows[] = array(
    	    $element['homescorename'.$count]['#value'],
          drupal_render($element['homescoretime'.$count]),
          drupal_render($element['homescoreplayer'.$count]),
    	  );
    	}else{
    		$homerows[] = array(
          $element['homescorename'.$count]['#value'],
          drupal_render($element['homescoretime'.$count]),
        );
    	}
    	unset($form['home']['homescorename'.$count]);
      unset($form['home']['homescoretime'.$count]);
      unset($form['home']['homescoreplayer'.$count]);
      //unset($form['home']['subon'.$count]);
    }
    ++$count;
  }
  $count = 0;
  while(isset($form['away']['awayscorename'.$count])) {
    $element = $form['away'];
    if(is_array($element['awayscoremethod'.$count])){
    	if(isset($element['awayscoreplayer'.$count])){
  	    $awayrows[] = array(
          $element['awayscorename'.$count]['#value'],
    	    drupal_render($element['awayscoretime'.$count]),
          drupal_render($element['awayscoreplayer'.$count]),
        );
    	}else{
    		$awayrows[] = array(
          $element['awayscorename'.$count]['#value'],
          drupal_render($element['awayscoretime'.$count]),
        );
    	}
      unset($form['away']['awayscorename'.$count]);
      unset($form['away']['awayscoretime'.$count]);
      unset($form['away']['awayscoreplayer'.$count]);
    }
    ++$count;
  }
  //Check how many columns we have. Only had the player column if we are rendering it.
  
  if(count($homerows[0]) == 2 || count($awayrows[0]) == 2){
    $homeheader = array($form['home_name']['#value'].' '.t('Scores'), t('Time'));
    $awayheader = array($form['away_name']['#value'].' '.t('Scores'), t('Time'));
  }else{
    $homeheader = array($form['home_name']['#value'].' '.t('Scores'), t('Time'), t('Player'));
  	$awayheader = array($form['away_name']['#value'].' '.t('Scores'), t('Time'), t('Player'));
  }
  if(count($homerows) > 0){
    $output = theme('table', $homeheader, $homerows);
  }
  $form['home'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  if(count($awayrows) > 0){
    $output = theme('table', $awayheader, $awayrows);
  }
  $form['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  return drupal_render($form);
}

function theme_leaguesite_scoring_home_penalties($form){
	//Go through all the form elements looking for players. Add them to a table setup
  foreach ($form as $name => $element) {
    if(is_array($element['homepentime'.$name])){
      if(isset($element['homepenplayer'.$name])){
        $penaltyrows[] = array(
          drupal_render($element['homepentime'.$name]),
          drupal_render($element['homepenplayer'.$name]),
          drupal_render($element['homepentype'.$name]),
        );
      }else{
        $penaltyrows[] = array(
          drupal_render($element['homepentime'.$name]),
          drupal_render($element['homepentype'.$name]),
        );
      }
      //Once we have added the players, we don't want to display them again, so we remove them from the original form.
      unset($form[$name]['homepentime'.$name]);
      unset($form[$name]['homepenplayer'.$name]);
      unset($form[$name]['homepentype'.$name]);
    }
  }
  
  
  //Check how many columns we have. Only had the player column if we are rendering it.
  if(count($penaltyrows[0]) == 2){
    $penheader = array(t('Time'), t('Penalty'));
  }else{
    $penheader = array(t('Time'), t('Player'), t('Penalty'));
  }
  if(count($penaltyrows) > 0){
    $output = theme('table', $penheader, $penaltyrows);
  }
  $form['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  
  
  return drupal_render($form);
}

function theme_leaguesite_scoring_away_penalties($form){
  //Go through all the form elements looking for players. Add them to a table setup
  foreach ($form as $name => $element) {
    if(is_array($element['awaypentime'.$name])){
      if(isset($element['awaypenplayer'.$name])){
        $penaltyrows[] = array(
          drupal_render($element['awaypentime'.$name]),
          drupal_render($element['awaypenplayer'.$name]),
          drupal_render($element['awaypentype'.$name]),
        );
      }else{
        $penaltyrows[] = array(
          drupal_render($element['awaypentime'.$name]),
          drupal_render($element['awaypentype'.$name]),
        );
      }
      //Once we have added the players, we don't want to display them again, so we remove them from the original form.
      unset($form[$name]['awaypentime'.$name]);
      unset($form[$name]['awaypenplayer'.$name]);
      unset($form[$name]['awaypentype'.$name]);
    }
  }
  
  
  //Check how many columns we have. Only had the player column if we are rendering it.
  if(count($penaltyrows[0]) == 2){
    $penheader = array(t('Time'), t('Penalty'));
  }else{
    $penheader = array(t('Time'), t('Player'), t('Penalty'));
  }
  if(count($penaltyrows) > 0){
    $output = theme('table', $penheader, $penaltyrows);
  }
  $form['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  
  
  return drupal_render($form);
}

function theme_leaguesite_scoring_away_substitutions($form){
	//Go through all the form elements looking for players. Add them to a table setup
  foreach ($form as $name => $element) {
    if(is_array($element['awaysubtime'.$name])){
      $subrows[] = array(
        drupal_render($element['awaysubtime'.$name]),
        drupal_render($element['awaysuboff'.$name]),
        drupal_render($element['awaysubon'.$name]),
      );
      //Once we have added the players, we don't want to display them again, so we remove them from the original form.
      unset($form[$name]['awaysubtime'.$name]);
      unset($form[$name]['awaysuboff'.$name]);
      unset($form[$name]['awaysubon'.$name]);
    }
  }
  
  //Check how many columns we have. Only had the position column if we are rendering it.
  $subheader = array(t('Time'), t('Player off'), t('Player on'));
  if(count($subrows) > 0){
    $output = theme('table', $subheader, $subrows);
  }
  $form['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  
  
  return drupal_render($form);
}

function theme_leaguesite_scoring_home_substitutions($form){
  //Go through all the form elements looking for players. Add them to a table setup
  foreach ($form as $name => $element) {
    if(is_array($element['homesubtime'.$name])){
      $subrows[] = array(
        drupal_render($element['homesubtime'.$name]),
        drupal_render($element['homesuboff'.$name]),
        drupal_render($element['homesubon'.$name]),
      );
      //Once we have added the players, we don't want to display them again, so we remove them from the original form.
      unset($form[$name]['homesubtime'.$name]);
      unset($form[$name]['homesuboff'.$name]);
      unset($form[$name]['homesubon'.$name]);
    }
  }
  
  //Check how many columns we have. Only had the position column if we are rendering it.
  $subheader = array(t('Time'), t('Player off'), t('Player on'));
  if(count($subrows) > 0){
    $output = theme('table', $subheader, $subrows);
  }
  $form['list'] = array('#type' => 'markup', '#weight' => -1, '#value' => $output);
  
  
  return drupal_render($form);
}

/**
 * General submit handler for ahah callbacks. 
 * @param unknown_type $form
 * @param unknown_type $form_state
 * @return unknown_type
 */
function leaguesite_scoring_ahah_submit($form, &$form_state) {
  $breakdown_selection = $form_state['values'];
  unset($form_state['submit_handlers']);
  form_execute_handlers('submit', $form, $form_state);
  $form_state['breakdown_selection'] = $breakdown_selection;
  $form_state['rebuild'] = TRUE; 
}

function leaguesite_scoring_create_breakdown_submit($form, $form_state){
	/*
	 * When this is saved, I should check for a previous iteration of the breakdown of this match. An insert acts as normal, an update will wipe the previous breakdown clean and re-insert.
	 * TODO: I should have a confirm form if the breakdown exists already.
	 */
	//only process the form if the 'save' button was clicked. Otherwise its an ahah callback.
	if($form_state['clicked_button']['#id'] == 'edit-submit'){
	 $match_id = intval($form_state['values']['match_id']);
  	$match = db_query('SELECT * FROM {leaguesite_event} WHERE match_id = %d', $match_id);
  	if(db_fetch_array($match)){
  		//this match exists. We should delete all of it to make sure it doesn't duplicate.
  		db_query('DELETE FROM {leaguesite_event} WHERE match_id = %d;', $match_id);
  	}
  	//pentime, penplayer (if set), pentype
  	//first away
  	$count = 0;
    while(isset($form_state['values']['homepentime'.$count]) && ($form_state['values']['homepentime'.$count] != '') && ($form_state['values']['homepentime'.$count] != 'none')){
      //deal with the penalty in the events table
    	if(!isset($form_state['values']['homepenplayer'.$count])){
      	$form_state['values']['homepenplayer'.$count] = -1;
      }else{
        if($form_state['values']['homepenplayertype'.$count] == 'textfield'){
          //Add the player to the database and then use the returned ID to add them to the breakdown database.
        	$form_state['values']['homepenplayer'.$count] = leaguesite_player_add_player_quick($form_state['values']['homepenplayer'.$count]);
        }
      }
      db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, pen_score_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'pen', intval($form_state['values']['homepentime'.$count]), intval($form_state['values']['homepenplayer'.$count]), intval($form_state['values']['homepentype'.$count]), intval($form_state['values']['home_team']));
      ++$count;
    }
    //now home
    $count = 0;
    while(isset($form_state['values']['awaypentime'.$count]) && ($form_state['values']['awaypentime'.$count] != '') && ($form_state['values']['awaypentime'.$count] != 'none')){
      //deal with the penalty in the events table
      
      if(!isset($form_state['values']['awaypenplayer'.$count])){
        $form_state['values']['awaypenplayer'.$count] = -1;
      }else{
        if($form_state['values']['awaypenplayertype'.$count] == 'textfield'){
          //Add the player and then use the returned ID to add them to the database.
          $form_state['values']['awaypenplayer'.$count] = leaguesite_player_add_player_quick($form_state['values']['awaypenplayer'.$count]);
        }
      }
      db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, pen_score_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'pen', intval($form_state['values']['awaypentime'.$count]), intval($form_state['values']['awaypenplayer'.$count]), intval($form_state['values']['awaypentype'.$count]), intval($form_state['values']['away_team']));
      ++$count;
    }
  	
  	//subtime, suboff, subon
  	$count = 0;
  	while(isset($form_state['values']['homesubtime'.$count]) && ($form_state['values']['homesubtime'.$count] != '')){
  	  //deal with the sub in the events table
  	  //TODO: Check to see if the player is an ID, or a name. If its a name, add it to the database and get the ID.
  	  //print $form_state['values']['homesubontype'.$count];
  	  //die();
  	  if($form_state['values']['homesubontype'.$count] == 'textfield'){
  	  	//Add the player and then use the returned ID to add them to the database.
  	  	//Remember to add both the player on and the player off!
  	  	$form_state['values']['homesubon'.$count] = leaguesite_player_add_player_quick($form_state['values']['homesubon'.$count]);
  	  	$form_state['values']['homesuboff'.$count] = leaguesite_player_add_player_quick($form_state['values']['homesuboff'.$count]);
  	  }
  	  db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, player_on_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'sub', intval($form_state['values']['homesubtime'.$count]), intval($form_state['values']['homesuboff'.$count]), intval($form_state['values']['homesubon'.$count]), intval($form_state['values']['home_team']));
  	  ++$count;
  	}
  	
    $count = 0;
    while(isset($form_state['values']['awaysubtime'.$count]) && ($form_state['values']['awaysubtime'.$count] != '')){
      //deal with the sub in the events table
      //TODO: Check to see if the player is an ID, or a name. If its a name, add it to the database and get the ID.
      if($form_state['values']['awaysubontype'.$count] == 'textfield'){
        //Add the player and then use the returned ID to add them to the database.
        //Remember to add both the player on and the player off!
        $form_state['values']['awaysubon'.$count] = leaguesite_player_add_player_quick($form_state['values']['awaysubon'.$count]);
        $form_state['values']['awaysuboff'.$count] = leaguesite_player_add_player_quick($form_state['values']['awaysuboff'.$count]);
      }
      db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, player_on_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'sub', intval($form_state['values']['awaysubtime'.$count]), intval($form_state['values']['awaysuboff'.$count]), intval($form_state['values']['awaysubon'.$count]), intval($form_state['values']['away_team']));
      ++$count;
    }
  	
  	/*
  	 * match_id event_type time player player_on pen_score_id
  	 */
  	
  	//awayscoretime, awayscoremethod, awayscoreplayer (if set)
    $count = 0;
    while(isset($form_state['values']['awayscoretime'.$count]) && ($form_state['values']['awayscoretime'.$count] != '')){
      //deal with the penalty in the events table
      if(!isset($form_state['values']['awayscoreplayer'.$count])){
        $form_state['values']['awayscoreplayer'.$count] = -1;
      }else{
        if($form_state['values']['awayscoreplayertype'.$count] == 'textfield'){
          //Add the player and then use the returned ID to add them to the database.
          $form_state['values']['awayscoreplayer'.$count] = leaguesite_player_add_player_quick($form_state['values']['awayscoreplayer'.$count]);
        }
      }
      db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, pen_score_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'score', intval($form_state['values']['awayscoretime'.$count]), intval($form_state['values']['awayscoreplayer'.$count]), intval($form_state['values']['awayscoremethod'.$count]), intval($form_state['values']['away_team']));
      ++$count;
    }
	 //homescoretime, homescoremethod, homescoreplayer (if set)
    $count = 0;
    while(isset($form_state['values']['homescoretime'.$count]) && ($form_state['values']['homescoretime'.$count] != '')){
      //deal with the penalty in the events table
      if(!isset($form_state['values']['homescoreplayer'.$count])){
        $form_state['values']['homescoreplayer'.$count] = -1;
      }else{
      	if($form_state['values']['homescoreplayertype'.$count] == 'textfield'){
        	
          //Add the player and then use the returned ID to add them to the database.
          $form_state['values']['homescoreplayer'.$count] = leaguesite_player_add_player_quick($form_state['values']['homescoreplayer'.$count]);
        }
      }
      db_query("INSERT INTO {leaguesite_event} (match_id, event_type, time, player_id, pen_score_id, team_id) VALUES (%d, '%s', %d, %d, %d, %d);", $match_id, 'score', intval($form_state['values']['homescoretime'.$count]), intval($form_state['values']['homescoreplayer'.$count]), intval($form_state['values']['homescoremethod'.$count]), intval($form_state['values']['home_team']));
      ++$count;
    }
	}
}

/**
 * Menu callback for AHAH additions. All are kept below this line, it gets repetitive and messy!
 */
function leaguesite_home_substitutions_options_js(){
  //copied from the POLL module. I need to modify this for correct AHAH Drupal implementation
  module_load_include('inc', 'node', 'node.pages');
  $form_state = array('storage' => NULL, 'submitted' => FALSE);
  $form_build_id = $_POST['form_build_id'];
  // Get the form from the cache.
  $form = form_get_cache($form_build_id, $form_state);
  $args = $form['#parameters'];
  $form_id = array_shift($args);
  // We will run some of the submit handlers so we need to disable redirecting.
  $form['#redirect'] = FALSE;
  // We need to process the form, prepare for that by setting a few internals
  // variables.
  $form['#post'] = $_POST;
  $form['#programmed'] = FALSE;
  $form_state['post'] = $_POST;
  //set the submit ID, so I know which button was pressed
  $form_state['post']['leaguesite_submit_id'] = 'homesubs';
  // Build, validate and if possible, submit the form.
  drupal_process_form($form_id, $form, $form_state);
  // This call recreates the form relying solely on the form_state that the
  // drupal_process_form set up.
  $form = drupal_rebuild_form($form_id, $form_state, $args, $form_build_id);
  // Render the new output.
  $choice_form = $form['homesubstitutions'];
  unset($choice_form['#prefix'], $choice_form['#suffix']); // Prevent duplicate wrappers.
  $output = theme('status_messages').drupal_render($choice_form);
  drupal_json(array('status' => TRUE, 'data' => $output));
}
function leaguesite_away_substitutions_options_js() {
  //copied from the POLL module. I need to modify this for correct AHAH Drupal implementation
  module_load_include('inc', 'node', 'node.pages');
  $form_state = array('storage' => NULL, 'submitted' => FALSE);
  $form_build_id = $_POST['form_build_id'];
  // Get the form from the cache.
  $form = form_get_cache($form_build_id, $form_state);
  $args = $form['#parameters'];
  $form_id = array_shift($args);
  // We will run some of the submit handlers so we need to disable redirecting.
  $form['#redirect'] = FALSE;
  // We need to process the form, prepare for that by setting a few internals
  // variables.
  $form['#post'] = $_POST;
  $form['#programmed'] = FALSE;
  $form_state['post'] = $_POST;
  //set the submit ID, so I know which button was pressed
  $form_state['post']['leaguesite_submit_id'] = 'awaysubs';
  // Build, validate and if possible, submit the form.
  drupal_process_form($form_id, $form, $form_state);
  // This call recreates the form relying solely on the form_state that the
  // drupal_process_form set up.
  $form = drupal_rebuild_form($form_id, $form_state, $args, $form_build_id);
  // Render the new output.
  $choice_form = $form['awaysubstitutions'];
  unset($choice_form['#prefix'], $choice_form['#suffix']); // Prevent duplicate wrappers.
  $output = theme('status_messages').drupal_render($choice_form);
  drupal_json(array('status' => TRUE, 'data' => $output));
}
/**
 * Menu callback for AHAH additions.
 */
function leaguesite_home_penalties_options_js() {
  //copied from the POLL module. I need to modify this for correct AHAH Drupal implementation
  module_load_include('inc', 'node', 'node.pages');
  $form_state = array('storage' => NULL, 'submitted' => FALSE);
  $form_build_id = $_POST['form_build_id'];
  // Get the form from the cache.
  $form = form_get_cache($form_build_id, $form_state);
  $args = $form['#parameters'];
  $form_id = array_shift($args);
  // We will run some of the submit handlers so we need to disable redirecting.
  $form['#redirect'] = FALSE;
  // We need to process the form, prepare for that by setting a few internals
  // variables.
  $form['#post'] = $_POST;
  $form['#programmed'] = FALSE;
  $form_state['post'] = $_POST;
  //set the submit ID, so I know which button was pressed
  $form_state['post']['leaguesite_submit_id'] = 'homepens';
  // Build, validate and if possible, submit the form.
  drupal_process_form($form_id, $form, $form_state);
  // This call recreates the form relying solely on the form_state that the
  // drupal_process_form set up.
  $form = drupal_rebuild_form($form_id, $form_state, $args, $form_build_id);
  // Render the new output.
  $choice_form = $form['homepenalties'];
  unset($choice_form['#prefix'], $choice_form['#suffix']); // Prevent duplicate wrappers.
  $output = theme('status_messages').drupal_render($choice_form);
  drupal_json(array('status' => TRUE, 'data' => $output));
}

function leaguesite_away_penalties_options_js() {
  //ahah callback for adding more away fields in the penalty fieldset
  module_load_include('inc', 'node', 'node.pages');
  $form_state = array('storage' => NULL, 'submitted' => FALSE);
  $form_build_id = $_POST['form_build_id'];
  // Get the form from the cache.
  $form = form_get_cache($form_build_id, $form_state);
  $args = $form['#parameters'];
  $form_id = array_shift($args);
  // We will run some of the submit handlers so we need to disable redirecting.
  $form['#redirect'] = FALSE;
  // We need to process the form, prepare for that by setting a few internals
  // variables.
  $form['#post'] = $_POST;
  $form['#programmed'] = FALSE;
  $form_state['post'] = $_POST;
  //set the submit ID, so I know which button was pressed
  $form_state['post']['leaguesite_submit_id'] = 'awaypens';
  // Build, validate and if possible, submit the form.
  drupal_process_form($form_id, $form, $form_state);
  // This call recreates the form relying solely on the form_state that the
  // drupal_process_form set up.
  $form = drupal_rebuild_form($form_id, $form_state, $args, $form_build_id);
  // Render the new output.
  $choice_form = $form['awaypenalties'];
  unset($choice_form['#prefix'], $choice_form['#suffix']); // Prevent duplicate wrappers.
  $output = theme('status_messages').drupal_render($choice_form);
  drupal_json(array('status' => TRUE, 'data' => $output));
}